# MICAPS数据格式

## 地面全要素填图(第一类数据格式)

```
# 文件头
diamond 1 13年03月03日02时地面填图
# 日期: %y %m %d %H BTC 最后的4位数字作用暂时不清楚
13 03 03 02 4107
# ID    经度     纬度    海拔  站点气压   不清楚   风向   风速 海平面气压 不清楚                               露点温度(摄氏)            温度(摄氏)
45032  113.98   22.47   35   222       9999     350    2   239       1     9999 9999 0 9999 9999 9999    7.2         9999 9999   12.4      9999 9999    1    2 9999 9999
```

其中，$真实气压=气压\times 10 + 100000$，单位Pa. 文件格式与[nmc_met_io](https://github.com/nmcdev/nmc_met_io/blob/master/nmc_met_io/read_micaps.py#L18)中的定义基本相同，除了站点气压(在nmc_met_io中变为站点级别).

## TLOGP和站点剖面图数据(第五类数据格式)

```
# 文件头
diamond 5 GTS-OBS decoded based on GEMPAK
# 日期: %y %m %d %H BTC, 553为该文件中的总站点数
13 03 03 08  553
# ID       经度     纬度      海拔   廓线层数  廓线层数
 1001    -8.66    70.93      9     12       52
    #  气压       高度     温度     露点      风向       风速
      1017.0     0.90    -5.30   -11.30    10.00     6.00
      1000.0    13.70    -5.90   -12.90    25.00     8.00
```

最后的廓线层数参数有1-2个不等，读取时需要额外进行判断.
